from .ternary import ter
from .quaternary import quat
from .quinary import quin
from .senary import sen
from .septenary import sept
from .nonary import non

__all__ = ["ter", "quat", "quin", "sen", "sept", "non"]